===================
 Contributor Guide
===================

Code is hosted at `git.openstack.org`__. Submit bugs to the python-freezerclient
project on `Launchpad`__. Submit code to the `openstack/python-freezerclient`
project using `Gerrit`__.

__ https://opendev.org/openstack/python-freezerclient
__ https://storyboard.openstack.org/#!/project/openstack/freezer-api
__ https://docs.openstack.org/infra/manual/developers.html#development-workflow


.. toctree::
   :maxdepth: 2

   testing
